@@ -139,7 +139,7 @@ function(object, ..., beta = c("none", "sd", "partial.sd"),
 
 	nModels <- length(models)
 	if(nModels == 1L) stop("only one model supplied. Nothing to do")
-	.checkModels(models)
+	checkIsModelDataIdentical(models)
 	
 	testSmoothKConsistency(models) # for gam, if any
 
